Gherkin.NimbleParser (Cucumber v0.9.0)

NimbleParsec-based Gherkin parser.

This module provides a compiled parser for Gherkin feature files using NimbleParsec. It produces the same output structs as the original parser for backward compatibility.

Architecture

The parser is built bottom-up in levels:

  • Level 1: Primitives (whitespace, newlines, rest_of_line)
  • Level 2: Keywords (Given, When, Then, Feature:, etc.)
  • Level 3: Elements (tags, datatables, docstrings)
  • Level 4: Steps (keyword + text + optional attachments)
  • Level 5: Scenarios (Background, Scenario, ScenarioOutline, Examples)
  • Level 6: Feature (top-level parser)

Summary

Functions

Parses a Gherkin feature file string into structured data.

Parses the given binary as parse_feature.

Functions

parse(gherkin_string)

Parses a Gherkin feature file string into structured data.

Returns a %Gherkin.Feature{} struct on success. Raises Gherkin.ParseError on failure.

parse_feature(binary, opts \\ [])

@spec parse_feature(binary(), keyword()) ::
  {:ok, [term()], rest, context, line, byte_offset}
  | {:error, reason, rest, context, line, byte_offset}
when line: {pos_integer(), byte_offset},
     byte_offset: non_neg_integer(),
     rest: binary(),
     reason: String.t(),
     context: map()

Parses the given binary as parse_feature.

Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the parse_feature (start position) as {line, offset_to_start_of_line}.

To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line.

Options

  • :byte_offset - the byte offset for the whole binary, defaults to 0
  • :line - the line and the byte offset into that line, defaults to {1, byte_offset}
  • :context - the initial context value. It will be converted to a map